==> kubernetes-model-kustomize-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/ImageFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageFluentImpl<A extends ImageFluent<A>> extends BaseFluent<A> implements ImageFluent<A>{
  public ImageFluentImpl() {
  }
  public ImageFluentImpl(Image instance) {
    this.withDigest(instance.getDigest()); 
    this.withName(instance.getName()); 
    this.withNewName(instance.getNewName()); 
    this.withNewTag(instance.getNewTag()); 
    this.withTagSuffix(instance.getTagSuffix()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String digest;
  private String name;
  private String newName;
  private String newTag;
  private String tagSuffix;
  private Map<String,Object> additionalProperties;
  public String getDigest() {
    return this.digest;
  }
  public A withDigest(String digest) {
    this.digest=digest; return (A) this;
  }
  public Boolean hasDigest() {
    return this.digest != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNewName() {
    return this.newName;
  }
  public A withNewName(String newName) {
    this.newName=newName; return (A) this;
  }
  public Boolean hasNewName() {
    return this.newName != null;
  }
  public String getNewTag() {
    return this.newTag;
  }
  public A withNewTag(String newTag) {
    this.newTag=newTag; return (A) this;
  }
  public Boolean hasNewTag() {
    return this.newTag != null;
  }
  public String getTagSuffix() {
    return this.tagSuffix;
  }
  public A withTagSuffix(String tagSuffix) {
    this.tagSuffix=tagSuffix; return (A) this;
  }
  public Boolean hasTagSuffix() {
    return this.tagSuffix != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageFluentImpl that = (ImageFluentImpl) o;
    if (digest != null ? !digest.equals(that.digest) :that.digest != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (newName != null ? !newName.equals(that.newName) :that.newName != null) return false;
    if (newTag != null ? !newTag.equals(that.newTag) :that.newTag != null) return false;
    if (tagSuffix != null ? !tagSuffix.equals(that.tagSuffix) :that.tagSuffix != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(digest,  name,  newName,  newTag,  tagSuffix,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (digest != null) { sb.append("digest:"); sb.append(digest + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (newName != null) { sb.append("newName:"); sb.append(newName + ","); }
    if (newTag != null) { sb.append("newTag:"); sb.append(newTag + ","); }
    if (tagSuffix != null) { sb.append("tagSuffix:"); sb.append(tagSuffix + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-kustomize-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/ImageFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageFluentImpl<A extends ImageFluent<A>> extends BaseFluent<A> implements ImageFluent<A>{
  public ImageFluentImpl() {
  }
  public ImageFluentImpl(Image instance) {
    if (instance != null) {
      this.withDigest(instance.getDigest());
      this.withName(instance.getName());
      this.withNewName(instance.getNewName());
      this.withNewTag(instance.getNewTag());
      this.withTagSuffix(instance.getTagSuffix());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String digest;
  private String name;
  private String newName;
  private String newTag;
  private String tagSuffix;
  private Map<String,Object> additionalProperties;
  public String getDigest() {
    return this.digest;
  }
  public A withDigest(String digest) {
    this.digest=digest; return (A) this;
  }
  public Boolean hasDigest() {
    return this.digest != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNewName() {
    return this.newName;
  }
  public A withNewName(String newName) {
    this.newName=newName; return (A) this;
  }
  public Boolean hasNewName() {
    return this.newName != null;
  }
  public String getNewTag() {
    return this.newTag;
  }
  public A withNewTag(String newTag) {
    this.newTag=newTag; return (A) this;
  }
  public Boolean hasNewTag() {
    return this.newTag != null;
  }
  public String getTagSuffix() {
    return this.tagSuffix;
  }
  public A withTagSuffix(String tagSuffix) {
    this.tagSuffix=tagSuffix; return (A) this;
  }
  public Boolean hasTagSuffix() {
    return this.tagSuffix != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageFluentImpl that = (ImageFluentImpl) o;
    if (!java.util.Objects.equals(digest, that.digest)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(newName, that.newName)) return false;

    if (!java.util.Objects.equals(newTag, that.newTag)) return false;

    if (!java.util.Objects.equals(tagSuffix, that.tagSuffix)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(digest,  name,  newName,  newTag,  tagSuffix,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (digest != null) { sb.append("digest:"); sb.append(digest + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (newName != null) { sb.append("newName:"); sb.append(newName + ","); }
    if (newTag != null) { sb.append("newTag:"); sb.append(newTag + ","); }
    if (tagSuffix != null) { sb.append("tagSuffix:"); sb.append(tagSuffix + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
